import { render, screen } from '@testing-library/react';

import RootLayout, { metadata } from '../layout';

// Mock next/font/google since it's not available in the test environment
jest.mock('next/font/google', () => ({
  Geist: () => ({
    variable: '--font-geist-sans',
  }),
  Geist_Mono: () => ({
    variable: '--font-geist-mono',
  }),
}));

// Mock globals.css import
jest.mock('../globals.css', () => ({}));

describe('RootLayout', () => {
  it('renders children correctly', () => {
    const testContent = <div data-testid='test-content'>Test content</div>;
    render(<RootLayout>{testContent}</RootLayout>);

    expect(screen.getByTestId('test-content')).toBeInTheDocument();
    expect(screen.getByTestId('test-content')).toHaveTextContent('Test content');
  });

  it('creates proper HTML structure', () => {
    const testContent = <div data-testid='layout-child'>Test</div>;
    render(<RootLayout>{testContent}</RootLayout>);

    // Verify the child component is rendered correctly
    expect(screen.getByTestId('layout-child')).toBeInTheDocument();
  });

  it('has correct metadata export', () => {
    expect(metadata).toBeDefined();
    expect(metadata.title).toBe('Create Next App');
    expect(metadata.description).toBe('Generated by create next app');
  });

  it('renders without errors', () => {
    const testContent = <div data-testid='render-test'>Test</div>;
    const view = render(<RootLayout>{testContent}</RootLayout>);

    // Verify the component renders successfully
    expect(screen.getByTestId('render-test')).toBeInTheDocument();
    expect(view.container).toBeInTheDocument();
  });
});
